package com.yidianling.medical.im

import android.content.Context
import android.content.Intent
import android.view.LayoutInflater
import android.view.View
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout
import com.chad.library.adapter.base.BaseQuickAdapter
import com.ydl.ydlcommon.base.BaseActivity
import com.ydl.ydlcommon.utils.StatusBarUtils
import com.ydl.ydlcommon.utils.Utils
import com.yidianling.im.R
import com.yidianling.medical.im.adapter.MedicalSystemListAdapter
import com.yidianling.medical.widgets.LoadMoreView
import kotlinx.android.synthetic.main.medical_system_list_activity.*

import kotlinx.coroutines.*
import java.util.*

/**
 * 系统消息列表
 * @author liupeng
 * */
class SystemMessageListActivity : BaseActivity(), SwipeRefreshLayout.OnRefreshListener,
    BaseQuickAdapter.RequestLoadMoreListener {
    private lateinit var mEmptyView: View
    private lateinit var mAdapter: MedicalSystemListAdapter

    companion object {
        private lateinit var mDoctorId: String
        private lateinit var mDoctorUid: String

        @JvmStatic
        fun start(context: Context, doctorId: String, doctorUid: String) {
            val starter = Intent(context, SystemMessageListActivity::class.java)
                .putExtra("doctorId", doctorId)
                .putExtra("doctorUid", doctorUid)
            context.startActivity(starter)
        }
    }

    override fun layoutResId(): Int {
        return R.layout.medical_system_list_activity
    }

    override fun initDataAndEvent() {
        initStatus()
        mEmptyView = LayoutInflater.from(this@SystemMessageListActivity)
            .inflate(R.layout.platform_list_empty_view, null, false)
        mAdapter = MedicalSystemListAdapter()
        system_list.layoutManager =
            LinearLayoutManager(this@SystemMessageListActivity, LinearLayoutManager.VERTICAL, false)
        system_list.adapter = mAdapter

        mAdapter.setOnItemClickListener { adapter, view, position ->
            if (Utils.isFastClick()) {
                //防止连击
                return@setOnItemClickListener
            }
        }
        mAdapter.setLoadMoreView(LoadMoreView())
        mAdapter.setOnLoadMoreListener(this@SystemMessageListActivity, system_list)
        system_swipe_refresh_layout?.setOnRefreshListener(this)

        system_swipe_refresh_layout?.setColorSchemeColors(
            ContextCompat.getColor(this@SystemMessageListActivity, R.color.platform_main_theme)
        )
        system_swipe_refresh_layout?.setProgressViewOffset(false, 0, 200)


    }



    override fun onRefresh() {


    }

    override fun onLoadMoreRequested() {

    }

    private fun initStatus() {
        StatusBarUtils.setTransparentForImageView(this@SystemMessageListActivity, null)
        StatusBarUtils.statusBarLightMode(this@SystemMessageListActivity)
    }


}